@@ -1107,7 +1107,7 @@ eog_image_real_load (EogImage *img,
 					eog_image_set_xmp_data (img, md_reader);
 #endif
 					set_metadata = FALSE;
-                                        priv->metadata_status = EOG_IMAGE_METADATA_READY;
+					priv->metadata_status = EOG_IMAGE_METADATA_READY;
 				}
 
 				if (data2read == EOG_IMAGE_DATA_EXIF)
@@ -1124,7 +1124,10 @@ eog_image_real_load (EogImage *img,
 	if (read_image_data || read_only_dimension) {
 #ifdef HAVE_RSVG
 		if (use_rsvg) {
-			rsvg_handle_close (priv->svg, error);
+			/* Ignore the error if loading failed earlier
+			 * as the error will already be set in that case */
+			rsvg_handle_close (priv->svg,
+			                   (failed ? NULL : error));
 		} else
 #endif
 		if (failed) {
@@ -1135,8 +1138,8 @@ eog_image_real_load (EogImage *img,
 				 * images as well. */
 				g_clear_error (error);
 			}
-	        }
-        }
+		}
+	}
 
 	g_free (buffer);
 
@@ -2432,6 +2435,14 @@ eog_image_get_svg (EogImage *img)
 }
 #endif
 
+/**
+ * eog_image_get_transform:
+ * @img: a #EogImage
+ *
+ * Get @img transform.
+ *
+ * Returns: (transfer none): A #EogTransform.
+ */
 
 EogTransform *
 eog_image_get_transform (EogImage *img)
@@ -2441,6 +2452,15 @@ eog_image_get_transform (EogImage *img)
 	return img->priv->trans;
 }
 
+/**
+ * eog_image_get_autorotate_transform:
+ * @img: a #EogImage
+ *
+ * Get @img autorotate transform.
+ *
+ * Returns: (transfer none): A #EogTransform.
+ */
+
 EogTransform*
 eog_image_get_autorotate_transform (EogImage *img)
 {
